//! Debug interface for the Boy emulator
#![allow(unused_imports)]

use boy::memory::{Bus, Cart};
use boy_debug::{
    bus::BusIOTools,
    cli::{lexer::Lexible, parser::Parsible},
    gameboy::Gameboy,
    message::Response,
};
use rustyline::{config::Configurer, history::FileHistory, Editor};
use std::error::Error;

fn main() -> Result<(), Box<dyn Error>> {
    // Set up the gameboy
    // TODO: move off the main thread
    let args: Vec<_> = std::env::args().collect();
    let mut bus = match args.len() {
        2 => vec![0; 0x10000].read_file(&args[1])?,
        _ => return Err(format!("Usage: {} [rom.gb]", args[0]).into()),
    };
    // let mut bus = Bus::new(Cart::new(bus));
    let mut gb = Gameboy::new(bus.ascii());

    // Set up and run the REPL
    let mut rl: Editor<(), FileHistory> = Editor::new()?;
    rl.set_auto_add_history(true);
    while let Ok(line) = rl.readline("\x1b[96mgb>\x1b[0m ") {
        for request in line.chars().lex().parse() {
            // TODO: Process requests in another thread, maybe
            match gb.process(request) {
                Response::Success => {}
                Response::Failure => println!(":("),
                Response::Data(data) => println!(" => 0x{data:02x} ({data})"),
            }
        }
    }
    Ok(())
}
